@@ -11,16 +11,11 @@ has appx_reset => ( is => 'lazy', isa => Enum [qw[CLEAR RESET]], init_arg => und
 has appx_parent => ( is => 'lazy', isa => Object, weak_ref => 1, init_arg => undef );
 has cfg => ( is => 'lazy', isa => HashRef, init_arg => undef );
 
-sub _build_appx_parent {
-    my $self = shift;
-
+sub _build_appx_parent ($self) {
     return $self->appx ? $self->appx : $self->app;
 }
 
-around _build_cfg => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around _build_cfg => sub ( $orig, $self ) {
     my $base_cfg = $self->appx_parent->cfg;
 
     $base_cfg->{ $self->_appx_key } //= {};
@@ -32,59 +27,45 @@ around _build_cfg => sub {
 };
 
 # this method can be oveloaded
-sub _build_cfg {
-    my $self = shift;
-
+sub _build_cfg ($self) {
     return;
 }
 
-around _create_local_cfg => sub {
-    my $orig     = shift;
-    my $self     = shift;
-    my $base_cfg = shift;
-
+around _create_local_cfg => sub ( $orig, $self, $base_cfg ) {
     if ( my $local_cfg = $self->$orig ) {
         $base_cfg->{ $self->_appx_key } //= {};
+
         P->hash->merge( $base_cfg->{ $self->_appx_key }, $local_cfg );
     }
 
     # create AppX local configs
-    for my $attr ( @{ $self->_appx_enum } ) {
+    for my $attr ( $self->_appx_enum->@* ) {
         my $attr_reader = $attr->{reader};
+
         $self->$attr_reader->_create_local_cfg( $base_cfg->{ $self->_appx_key } );
     }
 
     return;
 };
 
-sub _build_appx_reset {
-    my $self = shift;
-
+sub _build_appx_reset ($self) {
     return 'RESET';
 }
 
 # this method can be oveloaded
-sub _create_local_cfg {
-    my $self = shift;
-
+sub _create_local_cfg ($self) {
     return;
 }
 
-sub app_build {
-    my $self = shift;
-
+sub app_build ($self) {
     return;
 }
 
-sub app_deploy {
-    my $self = shift;
-
+sub app_deploy ($self) {
     return;
 }
 
-sub app_reset {
-    my $self = shift;
-
+sub app_reset ($self) {
     return;
 }
 
