@@ -19,6 +19,8 @@ if ($@) {
 }
 
 sub CORE_INIT ($proc_cfg) {
+    _normalize_inc();
+
     $PROC = Pcore::Core::Proc->new( $proc_cfg // () );
 
     # register util accessors
@@ -26,13 +28,12 @@ sub CORE_INIT ($proc_cfg) {
 
     _configure_inc();
 
-    _configure_inline();
-
     return;
 }
 
-sub _configure_inc {
+sub _normalize_inc {
     my @inc;
+
     my $inc_index;
 
     # index @INC, resolve @INC paths, remove duplicates, preserve REF items
@@ -43,12 +44,41 @@ sub _configure_inc {
             next;
         }
 
-        next if $inc_path eq q[.];    # ignore relative script path, added by perl automatically
+        # ignore relative script path, added by perl automatically
+        next if $inc_path eq q[.];
 
+        # ignore non-exists path
         next if !-d $inc_path;
 
         $inc_path = P->path( $inc_path, is_dir => 1 )->realpath->canonpath;
 
+        # ignore already added path
+        if ( !exists $inc_index->{$inc_path} ) {
+            $inc_index->{$inc_path} = 1;
+
+            push @inc, $inc_path;
+        }
+    }
+
+    @INC = @inc;    ## no critic qw[Variables::RequireLocalizedPunctuationVars]
+
+    return;
+}
+
+sub _configure_inc {
+    my @inc;
+
+    my $inc_index;
+
+    # index @INC, resolve @INC paths, remove duplicates, preserve REF items
+    for my $inc_path (@INC) {
+        if ( ref $inc_path ) {
+            push @inc, $inc_path;
+
+            next;
+        }
+
+        # ignore already added path
         if ( !exists $inc_index->{$inc_path} ) {
             $inc_index->{$inc_path} = 1;
 
@@ -58,28 +88,34 @@ sub _configure_inc {
 
     # not for PAR
     if ( !$PROC->is_par ) {
-        my $dist_lib_path;
+        my $is_module_build_test = $PROC->dist && exists $inc_index->{ $PROC->dist->root . 'blib/lib' } ? 1 : 0;
 
-        # add dist lib path
-        if ( $PROC->dist && -d $PROC->dist->root . 'lib/' && !exists $inc_index->{ $PROC->dist->root . 'lib' } ) {
-            $dist_lib_path = $PROC->dist->root . 'lib';
+        # add dist lib and PCORE_DIST_LIB to @INC only if we are int on the PAR archive and not in the Module::Build testing environment
+        # under Module::Build dist lib is already added and PCORE_DIST_LIB is not added to emulate clean CPAN installation
+        if ( !$is_module_build_test ) {
+            my $dist_lib_path;
 
-            $inc_index->{$dist_lib_path} = 1;
-        }
+            # detect dist lib path
+            if ( $PROC->dist && !exists $inc_index->{ $PROC->dist->root . 'lib' } && -d $PROC->dist->root . 'lib/' ) {
+                $dist_lib_path = $PROC->dist->root . 'lib';
 
-        # find and add other dist libs to @INC
-        if ( $ENV{PCORE_DIST_LIB} && -d $ENV{PCORE_DIST_LIB} ) {
-            for my $dir ( P->file->read_dir( $ENV{PCORE_DIST_LIB}, full_path => 1 )->@* ) {
-                if ( !exists $inc_index->{qq[$dir/lib]} && -d qq[$dir/lib/] && Pcore::Dist->dir_is_dist($dir) ) {
-                    $inc_index->{qq[$dir/lib]} = 1;
+                $inc_index->{$dist_lib_path} = 1;
+            }
 
-                    unshift @inc, qq[$dir/lib];
+            # find and add other dist libs to @INC
+            if ( $ENV{PCORE_DIST_LIB} && -d $ENV{PCORE_DIST_LIB} ) {
+                for my $dir ( sort { $b cmp $a } P->file->read_dir( $ENV{PCORE_DIST_LIB}, full_path => 1 )->@* ) {
+                    if ( !exists $inc_index->{qq[$dir/lib]} && -d qq[$dir/lib/] && Pcore::Dist->dir_is_dist($dir) ) {
+                        $inc_index->{qq[$dir/lib]} = 1;
+
+                        unshift @inc, qq[$dir/lib];
+                    }
                 }
             }
-        }
 
-        # register dist lib path in @INC, dist lib path is always on top of other dists
-        unshift @inc, $dist_lib_path if $dist_lib_path;
+            # register dist lib path in @INC, dist lib path is always on top of other dists
+            unshift @inc, $dist_lib_path if $dist_lib_path;
+        }
 
         # add absolute script path, only if not in PAR mode
         my $script_path = P->path( $PROC->{SCRIPT_DIR}, is_dir => 1 )->canonpath;
@@ -96,23 +132,6 @@ sub _configure_inc {
     return;
 }
 
-sub _configure_inline {
-    P->file->mkpath( $PROC->{INLINE_DIR} ) if !-d $PROC->{INLINE_DIR};
-
-    require Inline;
-
-    Inline->import(
-        config => (
-            directory         => $PROC->{INLINE_DIR},
-            autoname          => 0,
-            clean_after_build => 1,
-            clean_build_area  => 1,
-        )
-    );
-
-    return;
-}
-
 1;
 ## -----SOURCE FILTER LOG BEGIN-----
 ##
@@ -121,6 +140,8 @@ sub _configure_inline {
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
 ## │    3 │ 8                    │ ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
+## │    1 │ 107                  │ BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
