@@ -6,6 +6,9 @@ const our $TYPE => {
     Str => sub ($val) {
         return Str->check($val);
     },
+    Bool => sub ($val) {
+        return Bool->check($val);
+    },
     Int => sub ($val) {
         return Int->check($val);
     },
@@ -77,10 +80,10 @@ sub _validate_isa ( $self, @ ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 34                   │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_validate_isa' declared but not     │
+## │    3 │ 37                   │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_validate_isa' declared but not     │
 ## │      │                      │ used                                                                                                           │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 35                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 38                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
