@@ -5,6 +5,7 @@ use MooseX::GlobRef;
 use IO::Handle;
 
 extends qw[Moose::Object IO::Handle];
+
 with qw[MooseX::GlobRef::Role::Object];
 
 has level => ( is => 'ro', isa => Enum [qw[FATAL ERROR WARN INFO DEBUG]], default => 'INFO' );
@@ -24,4 +25,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Core::Log::Handle
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
