@@ -14,18 +14,22 @@ has res => ( is => 'lazy', isa => InstanceOf ['Pcore::Core::Proc::Resources'], i
 no Pcore;
 
 sub BUILD ( $self, $args ) {
-    $self->{START_DIR}    = P->file->cwd->to_string;
-    $self->{SCRIPT_NAME}  = $FindBin::RealScript;
-    $self->{SCRIPT_DIR}   = P->path( $FindBin::RealBin, is_dir => 1 )->realpath->to_string;
-    $self->{SCRIPT_PATH}  = $self->{SCRIPT_DIR} . $self->{SCRIPT_NAME};
-    $self->{SYS_TEMP_DIR} = P->path( File::Spec->tmpdir, is_dir => 1 )->to_string;
-    $self->{TEMP_DIR}     = P->file->tempdir( base => $self->{SYS_TEMP_DIR}, lazy => 1 );
+    $self->{START_DIR}      = P->file->cwd->to_string;
+    $self->{SCRIPT_NAME}    = $FindBin::RealScript;
+    $self->{SCRIPT_DIR}     = P->path( $FindBin::RealBin, is_dir => 1 )->realpath->to_string;
+    $self->{SCRIPT_PATH}    = $self->{SCRIPT_DIR} . $self->{SCRIPT_NAME};
+    $self->{SYS_TEMP_DIR}   = P->path( File::Spec->tmpdir, is_dir => 1 )->to_string;
+    $self->{TEMP_DIR}       = P->file->tempdir( base => $self->{SYS_TEMP_DIR}, lazy => 1 );
+    $self->{USER_DIR}       = P->path( $ENV{HOME} || $ENV{USERPROFILE}, is_dir => 1 );
+    $self->{PCORE_USER_DIR} = P->path( $self->{USER_DIR} . '.pcore/', is_dir => 1, lazy => 1 );
+    $self->{PCORE_SYS_DIR}  = P->path( $self->{SYS_TEMP_DIR} . '.pcore/', is_dir => 1, lazy => 1 );
+    $self->{INLINE_DIR}     = $self->is_par ? undef : P->path( $self->{PCORE_USER_DIR} . "inline/$Config::Config{version}/$Config::Config{archname}/", is_dir => 1, lazy => 1 );
 
     # load dist.perl
     if ( my $dist = $self->dist ) {
         $self->{CFG} = $args ? P->hash->merge( $dist->cfg, $args ) : $dist->cfg;
 
-        if ( $dist->is_par ) {
+        if ( $self->is_par ) {
             $self->{DATA_DIR} = undef;
             $self->{LOG_DIR} = P->path( $ENV{PAR_TEMP} . '/log/', is_dir => 1, lazy => 1 );
         }
@@ -41,19 +45,6 @@ sub BUILD ( $self, $args ) {
         $self->{LOG_DIR}  = undef;
     }
 
-    # conligure inline dir
-    if ( $self->dist && $self->dist->is_par ) {
-        $self->{INLINE_DIR} = P->path( $ENV{PAR_TEMP} . '/inc/' . $Config::Config{version} . q[/] . $Config::Config{archname} . q[/], is_dir => 1, lazy => 1 );
-    }
-    else {
-        if ( $self->pcore->is_installed ) {
-            $self->{INLINE_DIR} = P->path( $self->pcore->share_dir . '.inline/', is_dir => 1, lazy => 1 );
-        }
-        else {
-            $self->{INLINE_DIR} = P->path( $self->pcore->root . '.inline/' . $Config::Config{version} . q[/] . $Config::Config{archname} . q[/], is_dir => 1, lazy => 1 );
-        }
-    }
-
     return;
 }
 
@@ -71,11 +62,13 @@ sub _build_dist ($self) {
 }
 
 sub _build_pcore ($self) {
-    if ( $self->dist && $self->dist->name eq 'Pcore' ) {
+    my $pcore = Pcore::Dist->new('Pcore.pm');
+
+    if ( $self->dist && $self->dist->module->path eq $pcore->module->path ) {
         return $self->dist;
     }
     else {
-        return Pcore::Dist->new('Pcore.pm');
+        return $pcore;
     }
 }
 
