@@ -37,7 +37,7 @@ sub _chmod ($self) {
             q[.],
             sub ($path) {
                 if ( -d $path ) {
-                    P->file->chmod( 'rwx------', $path ) or print qq[$!: $path\n];
+                    P->file->chmod( 'rwx------', $path ) or say qq[$!: $path];
                 }
                 else {
                     my $is_exe;
@@ -50,14 +50,14 @@ sub _chmod ($self) {
                     }
 
                     if ($is_exe) {
-                        P->file->chmod( 'r-x------', $path ) or print qq[$!: $path\n];
+                        P->file->chmod( 'r-x------', $path ) or say qq[$!: $path];
                     }
                     else {
-                        P->file->chmod( 'rw-------', $path ) or print qq[$!: $path\n];
+                        P->file->chmod( 'rw-------', $path ) or say qq[$!: $path];
                     }
                 }
 
-                chown $>, $), $path or print qq[$!: $path\n];    # EUID, EGID
+                chown $>, $), $path or say qq[$!: $path];    # EUID, EGID
 
                 return;
             }
@@ -88,7 +88,7 @@ sub _cpanm ($self) {
             '--installdeps', q[.],
         );
 
-        print join( q[ ], @args ) . qq[\n];
+        say join q[ ], @args;
 
         Pcore->sys->system(@args) or return;
     }
@@ -98,28 +98,33 @@ sub _cpanm ($self) {
 
 sub _install ($self) {
     if ( !P->pm->is_superuser ) {
-        print qq[Root privileges required to deploy pcore at system level.\n];
+        say qq[Root privileges required to deploy pcore at system level.];
 
         return;
     }
 
-    my $canon_dist_root = P->file->cwd->realpath->canonpath;
+    my $canon_dist_root = P->path( $self->dist->root )->canonpath;
 
-    my $canon_bin_dir = P->path('./bin/')->realpath->canonpath;
+    my $canon_bin_dir = $canon_dist_root . '/bin';
 
-    my $canon_dist_lib_dir = P->path('./../')->realpath->canonpath;
+    my $canon_dist_lib_dir = P->path("$canon_dist_root/../")->realpath->canonpath;
 
     if ($MSWIN) {
 
         # set $ENV{PERL5LIB}
         P->sys->system(qq[setx.exe /M PERL5LIB "$canon_dist_root/lib;"]) or return;
 
-        print qq[%PERL5LIB% updated\n];
+        say qq[%PERL5LIB% updated];
 
         # set $ENV{PCORE_DIST_LIB}
         P->sys->system(qq[setx.exe /M PCORE_DIST_LIB "$canon_dist_lib_dir"]) or return;
 
-        print qq[%PCORE_DIST_LIB% updated\n];
+        say qq[%PCORE_DIST_LIB% updated];
+
+        # set $ENV{PCORE_RES_LIB}
+        P->sys->system(qq[setx.exe /M PCORE_RES_LIB "$canon_dist_lib_dir/resources"]) or return;
+
+        say qq[%PCORE_RES_LIB% updated];
 
         # update $ENV{PATH}
         require Win32::TieRegistry;
@@ -141,17 +146,20 @@ sub _install ($self) {
 
             P->sys->system(qq[setx.exe /M PATH "$ENV{PATH};"]) or return;
 
-            print qq[%PATH% updated\n];
+            say qq[%PATH% updated];
         }
     }
     else {
         my $data = <<"SH";
 export PERL5LIB="$canon_dist_root/lib:\$PERL5LIB"
 export PCORE_DIST_LIB="$canon_dist_lib_dir"
+export PCORE_RES_LIB="$canon_dist_lib_dir/resources"
 export PATH="\$PATH:$canon_bin_dir"
 SH
 
         P->file->write_bin( '/etc/profile.d/pcore.sh', { mode => q[rw-r--r--] }, \$data );
+
+        say '/etc/profile.d script installed';
     }
 
     return 1;
@@ -164,9 +172,10 @@ SH
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    2 │ 106                  │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
+## │    3 │ 101, 117, 122, 127,  │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
+## │      │ 149                  │                                                                                                                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 127                  │ ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     │
+## │    1 │ 132                  │ ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
