@@ -25,6 +25,22 @@ has exe_filename => ( is => 'lazy', isa => Str, init_arg => undef );
 
 no Pcore;
 
+our $PAR_DEPS = [    # common deps, will be included in any PAR
+
+    # following deps are needed to generate exception
+    'File/Path.pm',
+    'HTTP/Date.pm',
+    'Pcore/Core/H/Role.pm',
+    'Pcore/Core/H/Role/Wrapper.pm',
+    'Pcore/Handle/File.pm',
+    'Pcore/Util/Date.pm',
+    'Pcore/Util/Sys.pm',
+    'Time/Local.pm',
+    'Time/Moment.pm',
+    'Time/Zone.pm',
+    'bytes_heavy.pl',
+];
+
 sub _build_tree ($self) {
     return Pcore::Util::File::Tree->new;
 }
@@ -54,7 +70,7 @@ sub run ($self) {
     say BOLD . GREEN . qq[\nbuild] . ( $self->crypt ? ' crypted' : BOLD . RED . q[ not crypted] . BOLD . GREEN ) . qq[ "@{[$self->exe_filename]}" for $Config::Config{archname}] . RESET;
 
     # add common par deps packages to the script_deps
-    for my $pkg ( $self->par_deps->@* ) {
+    for my $pkg ( $PAR_DEPS->@*, $self->par_deps->@* ) {
         $self->script_deps->{$pkg} = 1;
     }
 
@@ -63,6 +79,9 @@ sub run ($self) {
         $self->script_deps->{$pkg} = 1;
     }
 
+    # replace Inline.pm with Pcore/Core/Inline.pm
+    $self->script_deps->{'Pcore/Core/Inline.pm'} = 1 if delete $self->script_deps->{'Inline.pm'};
+
     # add Filter::Crypto::Decrypt deps if crypt mode is used
     $self->script_deps->{'Filter/Crypto/Decrypt.pm'} = 1 if $self->crypt;
 
@@ -72,14 +91,14 @@ sub run ($self) {
     # add dist dist.perl
     $self->tree->add_file( 'share/dist.perl', $self->dist->share_dir . '/dist.perl' );
 
-    # add dist revision.txt
-    $self->tree->add_file( 'share/revision.txt', \$self->dist->revision );
+    # add dist build.perl
+    $self->tree->add_file( 'share/build.perl', $self->dist->create_build_info );
 
     # add Pcore dist.perl
     $self->tree->add_file( 'lib/auto/share/dist/Pcore/dist.perl', $PROC->res->get_lib('pcore') . 'dist.perl' );
 
-    # add Pcore revision.txt
-    $self->tree->add_file( 'lib/auto/share/dist/Pcore/revision.txt', \$PROC->pcore->revision );
+    # add Pcore build.perl
+    $self->tree->add_file( 'lib/auto/share/dist/Pcore/build.perl', $PROC->pcore->create_build_info );
 
     # add META.yml
     $self->tree->add_file( 'META.yml', P->data->to_yaml( { par => { clean => 1 } } ) ) if $self->clean;
@@ -89,7 +108,7 @@ sub run ($self) {
 
     # process script deps
     print 'adding deps ... ';
-    $self->_add_script_deps;
+    $self->_add_modules;
     say 'done';
 
     $self->_add_resources;
@@ -214,107 +233,53 @@ sub _add_shared_libs ($self) {
     return;
 }
 
-sub _add_script_deps ($self) {
-    for my $pkg ( grep {/[.](?:pl|pm)\z/sm} keys $self->script_deps->%* ) {
-        my $found = $self->_add_pkg($pkg);
+sub _add_modules ($self) {
+    for my $module ( grep {/[.](?:pl|pm)\z/sm} keys $self->script_deps->%* ) {
+        my $found = $self->_add_module($module);
 
-        $self->_error(qq[required deps wasn't found: $pkg]) if !$found && $self->script_deps->{$pkg} !~ /\A[(]eval\s/sm;
+        $self->_error(qq[required deps wasn't found: $module]) if !$found && $self->script_deps->{$module} !~ /\A[(]eval\s/sm;
     }
 
     return;
 }
 
-sub _add_pkg ( $self, $pkg ) {
-    $pkg = P->path($pkg);
+sub _add_module ( $self, $module ) {
+    $module = P->perl->module( $module, $self->dist->root . 'lib/' );
 
-    my $inc_path;
+    # module wasn't found
+    return if !$module;
 
-    my $located_in_cpan;
+    my $target;
 
-    # directly use './lib/' because dist can be located outside @INC
-    for ( grep { !ref } $self->dist->root . 'lib/', @INC ) {
-        if ( -f ( $_ . q[/] . $pkg ) ) {
-            $inc_path = P->path( $_, is_dir => 1 );
+    if ( my $auto_deps = $module->auto_deps ) {
 
-            $located_in_cpan = $inc_path->canonpath ~~ $self->dist->cpan_path ? 1 : 0;
+        # module have auto deps
+        $target = $Config::Config{version} . q[/] . $Config::Config{archname} . q[/];
 
-            last;
+        for my $deps ( keys $auto_deps->%* ) {
+            $self->tree->add_file( $target . $deps, $auto_deps->{$deps} );
         }
     }
-
-    # package wasn't found
-    return if !$inc_path;
-
-    my $target_base = 'lib/';
-
-    my $auto_base = 'auto/' . $pkg->dirname . $pkg->filename_base . q[/];
-
-    # find package shared objects
-    if ($located_in_cpan) {
-        if ( -d $inc_path . $auto_base ) {
-            my $pkg_so_filename = $pkg->filename_base . q[.] . $Config::Config{dlext};
-
-            my $pkg_so_source_path = $inc_path . $auto_base . $pkg_so_filename;
-
-            if ( -f $pkg_so_source_path ) {
-
-                # package has shared object in CPAN
-                $target_base = $Config::Config{version} . q[/] . $Config::Config{archname} . q[/];
-
-                $self->tree->add_file( $target_base . $auto_base . $pkg_so_filename, $pkg_so_source_path );
-
-                # add .ix, .al
-                P->file->find(
-                    $inc_path . $auto_base,
-                    dir => 0,
-                    sub ($path) {
-                        if ( $path->suffix eq 'ix' || $path->suffix eq 'al' ) {
-                            $self->tree->add_file( $target_base . $auto_base . $path, $inc_path . $auto_base . $path );
-                        }
-
-                        return;
-                    }
-                );
-            }
-        }
-    }
-
-    # find package inline deps
-    my $pkg_inline_source_base = $PROC->{INLINE_DIR} . q[lib/auto/] . $pkg->dirname . $pkg->filename_base . q[/] . $pkg->filename_base . q[.];
-
-    # package has inline shared object
-    if ( -f $pkg_inline_source_base . $Config::Config{dlext} ) {
-        $target_base = $Config::Config{version} . q[/] . $Config::Config{archname} . q[/];
-
-        my $pkg_inline_target_base = $target_base . q[auto/] . $pkg->dirname . $pkg->filename_base . q[/] . $pkg->filename_base . q[.];
-
-        # add inline shared object
-        $self->tree->add_file( $pkg_inline_target_base . $Config::Config{dlext}, $pkg_inline_source_base . $Config::Config{dlext} );
-
-        $self->tree->add_file( $pkg_inline_target_base . 'inl', $pkg_inline_source_base . 'inl' );
-
-        # add global inline config file
-        my $inline_config_name = 'config-' . $Config::Config{archname} . q[-] . $];
-
-        $self->tree->add_file( $target_base . $inline_config_name, $PROC->{INLINE_DIR} . $inline_config_name );
+    else {
+        $target = 'lib/';
     }
 
     # add .pm to the files tree
-    $self->_add_perl_source( $inc_path . $pkg, $target_base . $pkg, $located_in_cpan, $pkg );
+    $self->_add_perl_source( $module->path, $target . $module->name, $module->is_installed, $module->name );
 
     return 1;
 }
 
-sub _add_perl_source ( $self, $source, $target, $located_in_cpan = 0, $pkg = undef ) {
+sub _add_perl_source ( $self, $source, $target, $is_installed = 0, $module = undef ) {
     my $src = P->file->read_bin($source);
 
-    if ($pkg) {
+    if ($module) {
 
         # patch content for PAR compatibility
-        $src = PAR::Filter->new('PatchContent')->apply( $src, $pkg->to_string );
+        $src = PAR::Filter->new('PatchContent')->apply( $src, $module );
 
         # this is perl core or CPAN module
-        if ($located_in_cpan) {
+        if ($is_installed) {
             if ( $self->release ) {
                 $src = Pcore::Src::File->new(
                     {   action      => 'compress',
@@ -348,7 +313,7 @@ sub _add_perl_source ( $self, $source, $target, $located_in_cpan = 0, $pkg = und
         }
     }
 
-    my $crypt = $self->crypt && ( !$pkg || $pkg ne 'Filter/Crypto/Decrypt.pm' );
+    my $crypt = $self->crypt && ( !$module || $module ne 'Filter/Crypto/Decrypt.pm' );
 
     # we don't compress sources for devel build, preserving line numbers
     if ( !$self->release ) {
@@ -423,7 +388,7 @@ sub _compress_upx ( $self, $path ) {
 
     my $upx;
 
-    my $upx_cache_dir = $PROC->{SYS_TEMP_DIR} . '.pcore/upx-cache/';
+    my $upx_cache_dir = $PROC->{PCORE_SYS_DIR} . 'upx-cache/';
 
     if ($MSWIN) {
         $upx = $PROC->res->get('/bin/upx.exe');
@@ -447,6 +412,10 @@ sub _compress_upx ( $self, $path ) {
             }
             else {
                 push @files, $file;
+
+                # change permissions, so upx can overwrite file
+                # following will remove READ-ONLY attribute under windows
+                chmod 0777, $file or 1;
             }
         }
 
@@ -608,19 +577,19 @@ sub _error ( $self, $msg ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 182, 218, 544        │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 201, 237, 259, 513   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 195, 254, 286, 445   │ ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        │
+## │    3 │ 214, 410             │ ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 308                  │ Subroutines::ProhibitManyArgs - Too many arguments                                                             │
+## │    3 │ 273                  │ Subroutines::ProhibitManyArgs - Too many arguments                                                             │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 479                  │ RegularExpressions::ProhibitCaptureWithoutTest - Capture variable used outside conditional                     │
+## │    3 │ 448                  │ RegularExpressions::ProhibitCaptureWithoutTest - Capture variable used outside conditional                     │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 514                  │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
+## │    2 │ 483                  │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 566, 568             │ ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       │
+## │    2 │ 535, 537             │ ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 501, 507, 572        │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
+## │    1 │ 470, 476, 541        │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
