@@ -10,19 +10,19 @@ use overload                     #
     return $_[0]->to_string;
   },
   q[cmp] => sub {
-    my $self = shift;
-
-    return $_[1] ? $_[0] cmp $self->to_string : $self->to_string cmp $_[0];
+    return !$_[2] ? $_[0]->to_string cmp $_[1] : $_[1] cmp $_[0]->to_string;
   },
   q[~~] => sub {
-    my $self = shift;
-
-    return $_[1] ? $_[0] ~~ $self->to_string : $self->to_string ~~ $_[0];
+    return !$_[2] ? $_[0]->to_string ~~ $_[1] : $_[1] ~~ $_[0]->to_string;
+  },
+  q[-X] => sub {
+    return eval "-$_[1] '@{[$_[0]->encoded]}'";    ## no critic qw[BuiltinFunctions::ProhibitStringyEval]
   },
   fallback => undef;
 
-has to_string => ( is => 'lazy', clearer => '_clear_to_string', init_arg => undef );
-has to_uri    => ( is => 'lazy', clearer => '_clear_to_uri',    init_arg => undef );
+has to_string => ( is => 'lazy', init_arg => undef );
+has to_uri    => ( is => 'lazy', init_arg => undef );
+has encoded   => ( is => 'lazy', init_arg => undef );
 
 has lazy    => ( is => 'ro',   default  => 0 );
 has is_abs  => ( is => 'ro',   required => 1 );
@@ -34,12 +34,13 @@ has path      => ( is => 'ro',   required => 1 );                        # conta
 has canonpath => ( is => 'lazy', isa      => Str, init_arg => undef );
 
 has dirname       => ( is => 'lazy', isa => Str, init_arg => undef );
+has dirname_canon => ( is => 'lazy', isa => Str, init_arg => undef );
 has filename      => ( is => 'lazy', isa => Str, init_arg => undef );
 has filename_base => ( is => 'lazy', isa => Str, init_arg => undef );
 has suffix        => ( is => 'lazy', isa => Str, init_arg => undef );
 
 has default_mime_type => ( is => 'lazy', isa => Str, default => 'application/octet-stream' );
-has mime_type         => ( is => 'lazy', isa => Str );
+has mime_type         => ( is => 'ro',   isa => Str );
 has mime_category     => ( is => 'lazy', isa => Str );
 
 around new => sub ( $orig, $self, $path = q[], @ ) {
@@ -184,8 +185,71 @@ around new => sub ( $orig, $self, $path = q[], @ ) {
     return bless $path_args, $self;
 };
 
+around mime_type => sub ( $orig, $self, $shebang = undef ) {
+    return q[] if !$self->is_file;
+
+    if ( $shebang && !$self->{mime_type} && !$self->{_mime_type_shebang} ) {
+        $self->{_mime_type_shebang} = 1;
+
+        delete $self->{mime_type};
+    }
+
+    if ( !exists $self->{mime_type} ) {
+        \my $mime_types = \$self->_get_mime_types;
+
+        if ( exists $mime_types->{filename}->{ $self->filename } ) {
+            $self->{mime_type} = $mime_types->{filename}->{ $self->filename };
+        }
+        elsif ( my $suffix = $self->suffix ) {
+            if ( exists $mime_types->{suffix}->{$suffix} ) {
+                $self->{mime_type} = $mime_types->{suffix}->{$suffix};
+            }
+            elsif ( exists $mime_types->{suffix}->{ lc $suffix } ) {
+                $self->{mime_type} = $mime_types->{suffix}->{ lc $suffix };
+            }
+        }
+
+        if ( $shebang && !exists $self->{mime_type} ) {
+            my $buf_ref;
+
+            if ( ref $shebang ) {
+                $buf_ref = $shebang;
+            }
+            elsif ( -f $self ) {
+
+                # read first 50 bytes
+                P->file->read_bin(
+                    $self,
+                    buf_size => 50,
+                    cb       => sub {
+                        $buf_ref = $_[0] if $_[0];
+
+                        return;
+                    }
+                );
+            }
+
+            if ( $buf_ref && $buf_ref->$* =~ /\A(#!.+?)$/sm ) {
+                for my $mime_type ( keys $mime_types->{shebang}->%* ) {
+                    if ( $1 =~ $mime_types->{shebang}->{$mime_type} ) {
+                        $self->{mime_type} = $mime_type;
+
+                        last;
+                    }
+                }
+            }
+        }
+
+        $self->{mime_type} //= q[];
+    }
+
+    return $self->{mime_type} || $self->default_mime_type;
+};
+
 no Pcore;
 
+# apache MIME types
+# http://svn.apache.org/viewvc/httpd/httpd/trunk/docs/conf/mime.types?view=co
 our $MIME_TYPES;
 
 # Pcore::Util interface
@@ -229,6 +293,10 @@ sub _build_to_uri ($self) {
     return $uri;
 }
 
+sub _build_encoded ($self) {
+    return P->file->encode_path( $self->path );
+}
+
 sub _build_is_dir ($self) {
 
     # empty path is dir
@@ -246,6 +314,10 @@ sub _build_dirname ($self) {
     return substr $self->path, 0, rindex( $self->path, q[/] ) + 1;
 }
 
+sub _build_dirname_canon ($self) {
+    return $self->dirname =~ s[/\z][]smr;
+}
+
 sub _build_filename ($self) {
     return q[] if $self->path eq q[];
 
@@ -296,8 +368,12 @@ sub clone ($self) {
 }
 
 sub realpath ($self) {
-    if ( $self->is_dir && -d $self->path ) {
-        return $self->new( Cwd::realpath( $self->path ), is_dir => 1 );    # Cwd::realpath always return path without trailing "/"
+    if ( $self->is_dir ) {
+        my $path = $self->path eq q[] ? './' : $self->path;
+
+        return if !-d $path;
+
+        return $self->new( Cwd::realpath($path), is_dir => 1 );    # Cwd::realpath always return path without trailing "/"
     }
     elsif ( $self->is_file && -f $self->path ) {
         return $self->new( Cwd::realpath( Cwd::realpath( $self->path ) ) );
@@ -341,39 +417,35 @@ sub is_root ($self) {
 }
 
 # MIME
-sub _mime_types {
-    my $self = shift;
-
+sub _get_mime_types ($self) {
     unless ($MIME_TYPES) {
-        $MIME_TYPES = P->cfg->load( $P->{SHARE_DIR} . 'mime.perl' );
+        $MIME_TYPES = P->cfg->load( $PROC->res->get('/data/mime.perl') );
 
         # index MIME categories
         for my $suffix ( keys $MIME_TYPES->{suffix}->%* ) {
-            unless ( ref $MIME_TYPES->{suffix}->{$suffix} eq 'HASH' ) {
-                $MIME_TYPES->{suffix}->{$suffix} = { type => $MIME_TYPES->{suffix}->{$suffix}, };
+            my $type;
+
+            if ( ref $MIME_TYPES->{suffix}->{$suffix} eq 'HASH' ) {
+                $type = $MIME_TYPES->{suffix}->{$suffix}->{type};
+
+                $MIME_TYPES->{category}->{$type} = $MIME_TYPES->{suffix}->{$suffix}->{category} if $MIME_TYPES->{suffix}->{$suffix}->{category};
+
+                $MIME_TYPES->{suffix}->{$suffix} = $type;
+            }
+            else {
+                $type = $MIME_TYPES->{suffix}->{$suffix};
             }
 
-            $MIME_TYPES->{category}->{ $MIME_TYPES->{suffix}->{$suffix}->{type} } = $MIME_TYPES->{suffix}->{$suffix}->{category} if $MIME_TYPES->{suffix}->{$suffix}->{category};
+            if ( !$MIME_TYPES->{category}->{$type} && $type =~ m[\A(.+?)/]sm ) {
+                $MIME_TYPES->{category}->{$type} = $1;
+            }
         }
     }
 
     return $MIME_TYPES;
 }
 
-sub _build_mime_type {
-    my $self = shift;
-
-    if ( $self->is_file ) {
-        return $self->_mime_types->{suffix}->{ lc $self->suffix }->{type} // $self->default_mime_type;
-    }
-    else {
-        return q[];
-    }
-}
-
-sub _build_mime_category {
-    my $self = shift;
-
+sub _build_mime_category ($self) {
     if ( $self->mime_type ) {
         return $self->_mime_types->{category}->{ $self->mime_type } // q[];
     }
@@ -402,9 +474,13 @@ sub TO_DUMP {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 1                    │ Modules::ProhibitExcessMainComplexity - Main code has high complexity score (39)                               │
+## │    3 │ 1                    │ Modules::ProhibitExcessMainComplexity - Main code has high complexity score (58)                               │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 351                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 19                   │ ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
+## │    3 │ 233, 425             │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
+## │    2 │ 372                  │ ValuesAndExpressions::ProhibitNoisyQuotes - Quotes used with a noisy string                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
